pytilities.descriptors.attributedescriptor — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.descriptors »

# pytilities.descriptors.attributedescriptor

class `pytilities.dictionary.functionmap.` `FunctionMap`(mapper_function)

  A mapping based on a mapper function

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.descriptors »